@@ -1,5 +1,6 @@
 import json
 import os
+import select
 import subprocess
 import time
 
@@ -37,13 +38,16 @@ def newest_mtime(directory):
 class ApplyUpgrade:
     """Hook for system-image-cli"""
 
-    UPGRADER = "ubuntu-core-upgrade"
+    UPGRADER = ["ubuntu-core-upgrade"]
+    UPGRADER_ARGS = ["/writable/cache/ubuntu_command"]
 
     def apply_update(self):
-        # FIXME: hardcoded, this should probably be merged with the
-        #        two commands in bin/ anyway and all put here
         p = subprocess.Popen(
-            [self.UPGRADER, "/writable/cache/ubuntu_command"])
+            self.UPGRADER + self.UPGRADER_ARGS,
+            stdout=subprocess.PIPE, stderr=subprocess.STDOUT)
+        # collect the output while iterating to avoid hitting the 64k
+        # pipe size limit (unlikely but...)
+        stdout = ""
         while p.poll() is None:
             # send alive ping
             if config.dbus_service:
@@ -51,10 +55,15 @@ class ApplyUpgrade:
             if getattr(config, "machine_readable", False):
                 print("SPINNER:"+json.dumps({}))
             time.sleep(0.1)
+            if select.select([p.stdout.fileno()], [], []) != ([], [], []):
+                stdout += p.stdout.read().decode("utf-8", errors="replace")
+        # get return code
         ret_code = p.poll()
+        # close the pipes
+        p.communicate()
         if ret_code != 0:
             raise ApplyUpgradeError(
-                "%s exited with %s", self.UPGRADER, ret_code)
+                "%s exited with %s:\n%s", self.UPGRADER, ret_code, stdout)
         return True
 
     # FIXME: this is the entry point that system-image-cli uses, we need
